<?php
namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class SmParceiroNegocioFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function getContratosApenasDelphi(array $params) {
        $sql = "SELECT NRSEQCONTRATO
                  FROM CONTRATOLINP
                 WHERE NRSEQCONTRATO IS NULL
                   AND DTCONTLINPRESC IS NULL
                   AND NRORG     = :NRORG
                   AND CDCLIENTE = (SELECT CDCLIENTE 
                                      FROM CLIENTE 
                                     WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function inserirLogAltCnpjParceiro(array $params) {
        $sql = "INSERT INTO FCT_LOGALTCNPJPARCEIRO (
                    NRALTCNPJPARCEIRO, NROLDINSCRICAO, NRNEWINSCRICAO,
                    DTALTCNPJPARCEIRO, NMARQUIVO,      DSCAMINHOARQ,
                    DSTIPO,            VRTAMANHO,      IDATIVO,
                    DTINCLUSAO,        NRORGINCLUSAO,  NRORG,
                    CDOPERINCLUSAO,    DSJUSTIFICATIVA
                ) VALUES (
                    :NRALTCNPJPARCEIRO, :NROLDINSCRICAO, :NRNEWINSCRICAO,
                    SYSDATE,            :NMARQUIVO,      :DSCAMINHOARQ,
                    :DSTIPO,            :VRTAMANHO,      'S',
                    SYSDATE,            :NRORG,          :NRORG,
                    :CDOPERINCLUSAO,    :DSJUSTIFICATIVA
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getContratosParceiro(array $params) {
        $sql = "SELECT NRSEQCONTRATO
                  FROM FCT_CONTRATO
                 WHERE NRORG               = :NRORG
                   AND IDSITUACAOCONTRATO <> 'E'
                   AND IDATIVO             = 'S'
                   AND NRPARCNEGOCIO       IN (SELECT NRPARCNEGOCIO
                                                FROM PARCNEGOCIO
                                               WHERE NRINSCRICAOPARC = :NRINSCRICAOPARC)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function inserirAnexoContrato(array $params) {
        $sql = "INSERT INTO FCT_ANEXOCONTRATO (
                    NRANEXOCONTRATO, NRSEQCONTRATO,  NMARQUIVO,
                    DSCAMINHO,       DSTIPO,         VRTAMANHO,
                    NRORG,           DTINCLUSAO,     NRORGINCLUSAO,
                    CDOPERINCLUSAO,  IDATIVO
                ) VALUES (
                    :NRANEXOCONTRATO, :NRSEQCONTRATO,  :NMARQUIVO,
                    :DSCAMINHO,       :DSTIPO,         :VRTAMANHO,
                    :NRORG,           SYSDATE,         :NRORG,
                    :CDOPERINCLUSAO,  'S'
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getTermoAnuenciaParceiro(array $params) {
        $sql = "SELECT NMARQUIVO,
                       DSCAMINHOARQ,
                       DSTIPO,
                       VRTAMANHO
                  FROM FCT_LOGALTCNPJPARCEIRO
                 WHERE NRNEWINSCRICAO = :NRINSCRICAOPARC
                   AND NRORG          = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
        
    public function validaOrganizacao(array $params) {
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM ORGANIZACAO
                 WHERE NRINSJUREMPR = :NRINSJUREMPR 
                   AND IDATIVO = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $aux = $std->fetchAll();
        return $aux[0]["VALIDA"];
    }
    
    public function validaParceiro(array $params) {
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM PARCNEGOCIO
                 WHERE NRINSCRICAOPARC = :NRINSCRICAOPARC 
                   AND NRORG = :NRORG 
                   AND IDATIVO = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $aux = $std->fetchAll();
        return $aux[0]["VALIDA"];
    }
    
}
?>